@@ -1,6 +1,6 @@
 ﻿/**
  * @license Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.html or http://ckeditor.com/license
+ * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 (function() {
@@ -18,9 +18,8 @@
 			tab.remove( 'emailBody' );
 		} else if ( name == 'image' ) {
 			definition.removeContents( 'advanced' );
-//			tab = definition.getContents( 'Link' );
-//			tab.remove( 'cmbTarget' );
-			definition.removeContents( 'Link' );			// modified by naoki on 2013/6/19
+			tab = definition.getContents( 'Link' );
+			tab.remove( 'cmbTarget' );
 			tab = definition.getContents( 'info' );
 			tab.remove( 'txtAlt' );
 			tab.remove( 'basic' );
